// pre-commit makes sure the changed code is formatted and linted.
//
// Rationale:
// - Fixing formatting and linting errors are always fast and easy to fix.
// - This prevents over-complicated merge conflicts
// - This prevents small formatting/linting fix commits
"use strict";
const helpers_1 = require("../helpers/helpers");
const tsfmt = require("typescript-formatter");
const fs_1 = require("fs");
const path_1 = require("path");
const glob = require("glob");
/* tslint:disable:no-console */
let allTsFiles = () => {
    let tsConfig = JSON.parse(fs_1.readFileSync(path_1.join(process.cwd(), 'tsconfig.json'), 'UTF-8'));
    let globs = tsConfig && tsConfig.include ? tsConfig.include : ['src/**/*.ts', 'test/**/*.ts'];
    let files = [];
    globs.forEach(g => glob.sync(g).forEach(file => files.push(file)));
    return files;
};
let changed = helpers_1.findChangedFiles();
let files = changed.length === 0 ? allTsFiles() : helpers_1.filterTsFiles(changed);
tsfmt.processFiles(files, {
    verify: true, replace: false, verbose: false, baseDir: process.cwd(), editorconfig: true, tslint: true, tsfmt: true, tsconfig: true
}).then((resultList) => {
    let unformattedFiles = [];
    Object.keys(resultList).forEach((key) => {
        let result = resultList[key];
        if (result.error) {
            unformattedFiles.push(result.fileName);
        }
    });
    if (unformattedFiles.length === 0) {
        console.log(`All ${files.length} files were formatted`);
        process.exit(0);
    }
    else {
        console.error(`The following files were not formatted:\r\n  ${unformattedFiles.join('\r\n  ')}`);
        process.exit(1);
    }
});
//# sourceMappingURL=pre-commit.js.map